@@ -3,7 +3,7 @@
 	exFAT file system implementation library.
 
 	Free exFAT implementation.
-	Copyright (C) 2010-2017  Andrew Nayenko
+	Copyright (C) 2010-2018  Andrew Nayenko
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -855,7 +855,8 @@ static int find_slot(struct exfat* ef, struct exfat_node* dir,
 					free(dmap);
 					return -EIO;
 				case -EINVAL:
-					/* slot is occupied, continue searching */
+					/* slot at (i-n) is occupied, go back and check (i-n+1) */
+					i -= contiguous - 1;
 					contiguous = 0;
 					break;
 				}
